---
title: 연동방식
category: 서비스 종류 (결제대행사별 지원서비스) > 연동방식 > 연동방식
seo:
  title: 연동방식
  description: >-
    결제창 방식과 API 방식으로 제공되는 포트원의 연동방식 안내입니다. 유저의 결제 경험에 큰 영향을 미치는 결제 화면 UI가 관련된 매우
    중요한 요소이며, 결제대행사를 고르기 전 아주 중요한 기준이 됩니다.
  keywords:
    - 연동방식
    - 결제창방식
    - API
    - SDK
    - 인증결제
    - 비인증결제
tags:
  - 연동방식
  - 결제창
  - API
pgCompanies:
  - 공통
searchTags:
  - API방식
  - 결제창방식
  - 결제모듈
---

<Callout content="포트원을 통해 결제연동 하실 때 구분되는 연동방식의 종류를 안내드립니다.
연동 방식은 **개발 방법**에도 차이가 있지만, 고객 경험에 영향을 주는 **결제화면 UI** 에도 차이가 있기 때문에
결제대행사를 고르시기 전 중요한 기준이 될 수 있습니다." />

## <Highlight text="연동방식의 종류" />

### **결제창 방식**

결제대행사(PG사)에서 제공하는 결제창을 이용하여 결제하는 방식을 의미합니다.\
결제창 화면 UI 및 구성을 변경할 수는 없으나 반대로 추가 개발 없이 결제대행사에서 제공하는 화면을 그대로 사용할 수 있다는 특징이 있습니다.

일반적인 이커머스에서 구현하시는 단건결제(일회성결제) 에서 가장 많이 사용하시는 방식입니다.\
참고로 결제창 내 표기되는 항목들은 결제방식(일반결제, 정기결제 등)에 따라 상이할 수 있습니다.



### **API 방식**

결제대행사(PG사)에서 제공하는 결제창을 이용하지 않고 결제화면 UI를 직접 만드는 방식을 의미합니다. 결제요청이 API 로 이루어지기 때문에 유저에게 노출되는 결제 화면은 고객사에서 직접 만들어야 합니다. 이러한 점에서 원하시는 브랜드 이미지로 결제화면을 맞춤형으로 제작이 가능하며 반대로 추가적인 화면 구현 개발이 필요하다는 특징이 있습니다.

또한 결제창 방식과 다르게 카드사 인증과정이 생략되어있기 때문에 간편하게 결제가 가능하나 동시에 인증 과정이 생략되었기 때문에 이용을 원할 시 결제대행사측의 추가 심사가 필요할 수 있습니다.

